precision mediump float;
// LIGHT
uniform vec4 u_light_position;
uniform vec4 u_light_ambient_color;
uniform vec4 u_light_diffuse_color;
uniform vec4 u_light_specular_color;

// MATERIAL
uniform vec4 u_material_ambient_color;
uniform vec4 u_material_diffuse_color;
uniform vec4 u_material_specular_color;

attribute vec4 a_Position;
attribute vec2 a_TexCoord0;
attribute vec3 a_Normal;

uniform mat4 u_MVMatrix;
uniform mat4 u_PMatrix;
uniform mat4 u_VMatrix;
uniform mat4 u_it_MVMatrix;
uniform vec3 u_EyePosition;

varying vec2 v_TexCoord0;
varying vec4 v_FinalColor;

void main() {
    vec4 modelViewVertex = u_MVMatrix * a_Position;
    vec3 modelViewNormal = vec3(u_MVMatrix * vec4(a_Normal, 0.0));

    vec3 lightVector = normalize(u_light_position.xyz - modelViewVertex.xyz);

    float diffuse = max(dot(modelViewNormal, lightVector),0.0);
    float specular = smoothstep(0.85,1.0,diffuse);

    vec4 diffuseColor = u_material_diffuse_color * (diffuse + specular);
    v_FinalColor = u_light_ambient_color + diffuseColor;

    float distFromCamera = length(u_EyePosition - modelViewVertex.xyz);
    float ss = smoothstep(3.0, 4.0, distFromCamera);
    v_FinalColor.a = ss;

    v_TexCoord0 = a_TexCoord0;

    gl_Position = u_PMatrix * modelViewVertex;
}
